
TODO: TODO_84_71_86_21: realistic useful config only command example

NOTE: It is possible that config_only delegator may be useless due to limited applicability of
      providing what should be a logic in code via config. It seems too cumbersome to cover
      all cases to reach usefulness of such delegator. It is way easier to implement
      it directly in Python.

Current example for `DelegatorConfigOnly` is useless with primitive `echo` command.

Propose and pre-configure a better (realistic) command in `argrelay_plugin.yaml` which is:
*   fit the use case of `DelegatorConfigOnly`
    (not like `git` which actually deserves its own plugin with some logic to execute, not just manual data entry)
*   used by many
    (not some over-specialized command)
*   useful example
    (not simply for the sake of example)

